ClassicalFooter class

经典Footer

Inheritance

Constructors

ClassicalFooter({double extent = 60.0, double triggerDistance = 70.0, bool float = false, Duration? completeDuration = const Duration(seconds: 1), bool enableInfiniteLoad = true, bool enableHapticFeedback = true, bool overScroll = false, bool safeArea = true, EdgeInsets? padding, Key? key, AlignmentGeometry? alignment, String? loadText, String? loadReadyText, String? loadingText, String? loadedText, String? loadFailedText, String? noMoreText, bool showInfo = true, String? infoText, Color bgColor = Colors.transparent, Color textColor = Colors.black, Color infoColor = Colors.teal})

Properties

alignment → AlignmentGeometry?
方位
final
bgColor → Color
背景颜色
final
completeDuration → Duration?
finalinherited
enableHapticFeedback → bool
开启震动反馈
finalinherited
enableInfiniteLoad → bool
是否开启无限加载
finalinherited
extent → double
Footer容器高度
finalinherited
float → bool
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
infoColor → Color
更多信息文字颜色
final
infoText → String?
更多信息
final
key → Key?
Key
final
loadedText → String?
加载完成文字
final
loadFailedText → String?
加载失败文字
final
loadingText → String?
正在加载文字
final
loadReadyText → String?
准备加载文字
final
loadText → String?
提示加载文字
final
noMoreText → String?
没有更多文字
final
overScroll → bool
越界滚动(enableInfiniteLoad为true生效)
finalinherited
padding → EdgeInsets?
内边距(根据布局合理使用,设置后safeArea无效)
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeArea → bool
安全区域
finalinherited
showInfo → bool
显示额外信息(默认为时间)
final
textColor → Color
字体颜色
final
triggerDistance → double
高度(超过这个高度触发加载)
finalinherited

Methods

builder(BuildContext context, EasyRefresh easyRefresh, ValueNotifier<bool> focusNotifier, ValueNotifier<TaskState> taskNotifier, ValueNotifier<bool> callLoadNotifier, ValueNotifier<double> extraExtentNotifier) → Widget
inherited
contentBuilder(BuildContext context, LoadMode loadState, double pulledExtent, double loadTriggerPullDistance, double loadIndicatorExtent, AxisDirection axisDirection, bool float, Duration? completeDuration, bool enableInfiniteLoad, bool success, bool noMore) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited