CustomFooter class

通用Footer构造器

Inheritance

Constructors

CustomFooter({dynamic extent = 60.0, dynamic triggerDistance = 70.0, dynamic float = false, dynamic completeDuration, dynamic enableInfiniteLoad = false, dynamic enableHapticFeedback = false, required LoadControlBuilder footerBuilder})

Properties

completeDuration → Duration?
finalinherited
enableHapticFeedback → bool
开启震动反馈
finalinherited
enableInfiniteLoad → bool
是否开启无限加载
finalinherited
extent → double
Footer容器高度
finalinherited
float → bool
finalinherited
footerBuilder → LoadControlBuilder
Footer构造器
final
hashCode → int
The hash code for this object.
no setterinherited
overScroll → bool
越界滚动(enableInfiniteLoad为true生效)
finalinherited
padding → EdgeInsets?
内边距(根据布局合理使用,设置后safeArea无效)
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeArea → bool
安全区域
finalinherited
triggerDistance → double
高度(超过这个高度触发加载)
finalinherited

Methods

builder(BuildContext context, EasyRefresh easyRefresh, ValueNotifier<bool> focusNotifier, ValueNotifier<TaskState> taskNotifier, ValueNotifier<bool> callLoadNotifier, ValueNotifier<double> extraExtentNotifier) → Widget
inherited
contentBuilder(BuildContext context, LoadMode loadState, double pulledExtent, double loadTriggerPullDistance, double loadIndicatorExtent, AxisDirection axisDirection, bool float, Duration? completeDuration, bool enableInfiniteLoad, bool success, bool noMore) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited