Footer class abstract

Header

Implementers

Constructors

Footer({double extent = 60.0, double triggerDistance = 70.0, bool float = false, Duration? completeDuration, bool enableInfiniteLoad = true, bool enableHapticFeedback = false, bool overScroll = false, bool safeArea = false, EdgeInsets? padding})

Properties

completeDuration → Duration?
final
enableHapticFeedback → bool
开启震动反馈
final
enableInfiniteLoad → bool
是否开启无限加载
final
extent → double
Footer容器高度
final
float → bool
final
hashCode → int
The hash code for this object.
no setterinherited
overScroll → bool
越界滚动(enableInfiniteLoad为true生效)
final
padding → EdgeInsets?
内边距(根据布局合理使用,设置后safeArea无效)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeArea → bool
安全区域
final
triggerDistance → double
高度(超过这个高度触发加载)
final

Methods

builder(BuildContext context, EasyRefresh easyRefresh, ValueNotifier<bool> focusNotifier, ValueNotifier<TaskState> taskNotifier, ValueNotifier<bool> callLoadNotifier, ValueNotifier<double> extraExtentNotifier) → Widget
contentBuilder(BuildContext context, LoadMode loadState, double pulledExtent, double loadTriggerPullDistance, double loadIndicatorExtent, AxisDirection axisDirection, bool float, Duration? completeDuration, bool enableInfiniteLoad, bool success, bool noMore) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited