Header class abstract

Header

Implementers

Constructors

Header({double extent = 60.0, double triggerDistance = 70.0, bool float = false, Duration? completeDuration, bool enableInfiniteRefresh = false, bool enableHapticFeedback = false, bool overScroll = true})

Properties

completeDuration → Duration?
完成延时
final
enableHapticFeedback → bool
开启震动反馈
final
enableInfiniteRefresh → bool
是否开启无限刷新
final
extent → double
Header容器高度
final
float → bool
是否浮动
final
hashCode → int
The hash code for this object.
no setterinherited
overScroll → bool
越界滚动(enableInfiniteRefresh为true生效)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerDistance → double
触发刷新高度
final

Methods

builder(BuildContext context, EasyRefresh easyRefresh, ValueNotifier<bool> focusNotifier, ValueNotifier<TaskState> taskNotifier, ValueNotifier<bool> callRefreshNotifier) → Widget
contentBuilder(BuildContext context, RefreshMode refreshState, double pulledExtent, double refreshTriggerPullDistance, double refreshIndicatorExtent, AxisDirection axisDirection, bool float, Duration? completeDuration, bool enableInfiniteRefresh, bool success, bool noMore) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited