TaurusHeader class

冲上云霄Header

Inheritance

Constructors

TaurusHeader({Key? key, Color? backgroundColor = Colors.blue, bool enableHapticFeedback = false, Duration completeDuration = const Duration(seconds: 1)})

Properties

backgroundColor → Color?
背景色
final
completeDuration → Duration?
完成延时
finalinherited
enableHapticFeedback → bool
开启震动反馈
finalinherited
enableInfiniteRefresh → bool
是否开启无限刷新
finalinherited
extent → double
Header容器高度
finalinherited
float → bool
是否浮动
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Key
final
linkNotifier → LinkHeaderNotifier
final
overScroll → bool
越界滚动(enableInfiniteRefresh为true生效)
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerDistance → double
触发刷新高度
finalinherited

Methods

builder(BuildContext context, EasyRefresh easyRefresh, ValueNotifier<bool> focusNotifier, ValueNotifier<TaskState> taskNotifier, ValueNotifier<bool> callRefreshNotifier) → Widget
inherited
contentBuilder(BuildContext context, RefreshMode refreshState, double pulledExtent, double refreshTriggerPullDistance, double refreshIndicatorExtent, AxisDirection axisDirection, bool float, Duration? completeDuration, bool enableInfiniteRefresh, bool success, bool noMore) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited